@@ -1,7 +1,7 @@
 ## no critic (ProhibitStringyEval ProhibitSubroutinePrototypes RequireLocalizedPunctuationVars)
 package Test::Expander;
 
-our $VERSION = '1.0.4';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
+our $VERSION = '1.0.5';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
 
 use v5.14;
 use warnings
@@ -9,6 +9,7 @@ use warnings
   NONFATAL => qw(deprecated exec internal malloc newline portable recursion);
 no if ($] >= 5.018), warnings => 'experimental';
 
+use B                qw(svref_2object);
 use Const::Fast;
 use File::chdir;
 use File::Temp       qw(tempdir tempfile);
@@ -18,6 +19,7 @@ use Scalar::Readonly qw(readonly_on);
 use Test::Files;
 use Test::Output;
 use Test::Warn;
+use Test2::Tools::Basic;
 use Test2::Tools::Explain;
 use Test2::V0        ();
 
@@ -105,28 +107,29 @@ sub import {
   _setEnv($METHOD, $options{-target}, $testFile);
 
   Test2::V0->import(%options);
-  $METHOD_REF = '-target' ~~ %options ? $CLASS->can($METHOD) : undef;
-  $METHOD     = undef unless($METHOD_REF);
 
   if ($CLASS) {
     readonly_on($CLASS);
-    note(q(Set $CLASS to '),      $CLASS,      q('));
+    note(q(Set $CLASS to '),      $CLASS,                                                                   q('));
+
+    $METHOD_REF = $CLASS->can($METHOD);
+    $METHOD     = undef unless($METHOD_REF);
   }
   if ($METHOD) {
     readonly_on($METHOD);
-    note(q(Set $METHOD to '),     $METHOD,     q('));
+    note(q(Set $METHOD to '),     $METHOD,                                                                  q('));
   }
   if ($METHOD_REF) {
     readonly_on($METHOD_REF);
-    note(q(Set $METHOD_REF to '), $METHOD_REF, q('));
+    note(q(Set $METHOD_REF to '), $METHOD_REF, ' -> &', $CLASS, '::', svref_2object($METHOD_REF)->GV->NAME, q('));
   }
   if ($TEMP_DIR) {
     readonly_on($TEMP_DIR);
-    note(q(Set $TEMP_DIR to '),   $TEMP_DIR,   q('));
+    note(q(Set $TEMP_DIR to '),   $TEMP_DIR,                                                                q('));
   }
   if ($TEMP_FILE) {
     readonly_on($TEMP_FILE);
-    note(q(Set $TEMP_FILE to '),  $TEMP_FILE,  q('));
+    note(q(Set $TEMP_FILE to '),  $TEMP_FILE,                                                               q('));
   }
 
   Importer->import_into($class, scalar(caller), ());
